==> xlniuxdata-mobileauditplatform-1.0.0-sources.jar: com/xunlei/niux/data/auditplatform/vo/AuditMobileGameInfo.java <==
package com.xunlei.niux.data.auditplatform.vo;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by jamesjxin on 14-7-23.
 */
@Table(tableName = "auditmobilegameinfo", pkFieldAssign = false, pkFieldName = "seqId")
public class AuditMobileGameInfo {
    private Integer seqId;
    private Long userId;
    private String userEmail;
    private String userName;
    private String gameFullName;
    private String gameNamePinYin;
    private String appName;
    private Double appSize;
    private String versionNum;
    private String apkDownLoadUrl;
    private String gameMaterialUrl;
    private String gameIntroduction;
    private String gameDetailInfomation;
    private String currencyName;
    private Integer currencyExchangeRate;
    private Integer auditStatus;
    private String recordTime;
    private String auditTime;
    private String payCallBackUrl;

    private String business_QQ;
    private String business_mobile;
    private String business_email;
    private String tech_QQ;
    private String tech_mobile;
    private String tech_email;
    private String operation_QQ;
    private String operation_mobile;
    private String operation_email;
    private String customerService_QQ;
    private String customerService_mobile;
    private String customerService_email;
    private String accountCheck_QQ;
    private String accountCheck_mobile;
    private String accountCheck_email;
    private String auditGameId;
    private String companyName;
    private Boolean isH5Game;
    private String h5LoginUrl;

    public Integer getSeqId() {
        return seqId;
    }

    public void setSeqId(Integer seqId) {
        this.seqId = seqId;
    }

    public String getGameFullName() {
        return gameFullName;
    }

    public void setGameFullName(String gameFullName) {
        this.gameFullName = gameFullName;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Double getAppSize() {
        return appSize;
    }

    public void setAppSize(Double appSize) {
        this.appSize = appSize;
    }

    public String getVersionNum() {
        return versionNum;
    }

    public void setVersionNum(String versionNum) {
        this.versionNum = versionNum;
    }

    public String getApkDownLoadUrl() {
        return apkDownLoadUrl;
    }

    public void setApkDownLoadUrl(String apkDownLoadUrl) {
        this.apkDownLoadUrl = apkDownLoadUrl;
    }

    public String getGameMaterialUrl() {
        return gameMaterialUrl;
    }

    public void setGameMaterialUrl(String gameMaterialUrl) {
        this.gameMaterialUrl = gameMaterialUrl;
    }

    public String getGameIntroduction() {
        return gameIntroduction;
    }

    public void setGameIntroduction(String gameIntroduction) {
        this.gameIntroduction = gameIntroduction;
    }

    public String getGameDetailInfomation() {
        return gameDetailInfomation;
    }

    public void setGameDetailInfomation(String gameDetailInfomation) {
        this.gameDetailInfomation = gameDetailInfomation;
    }

    public String getCurrencyName() {
        return currencyName;
    }

    public void setCurrencyName(String currencyName) {
        this.currencyName = currencyName;
    }

    public Integer getCurrencyExchangeRate() {
        return currencyExchangeRate;
    }

    public void setCurrencyExchangeRate(Integer currencyExchangeRate) {
        this.currencyExchangeRate = currencyExchangeRate;
    }

    public Integer getAuditStatus() {
        return auditStatus;
    }

    public void setAuditStatus(Integer auditStatus) {
        this.auditStatus = auditStatus;
    }

    public String getRecordTime() {
        return recordTime;
    }

    public void setRecordTime(String recordTime) {
        this.recordTime = recordTime;
    }

    public String getAuditTime() {
        return auditTime;
    }

    public void setAuditTime(String auditTime) {
        this.auditTime = auditTime;
    }

    public String getBusiness_QQ() {
        return business_QQ;
    }

    public void setBusiness_QQ(String business_QQ) {
        this.business_QQ = business_QQ;
    }

    public String getBusiness_mobile() {
        return business_mobile;
    }

    public void setBusiness_mobile(String business_mobile) {
        this.business_mobile = business_mobile;
    }

    public String getBusiness_email() {
        return business_email;
    }

    public void setBusiness_email(String business_email) {
        this.business_email = business_email;
    }

    public String getTech_QQ() {
        return tech_QQ;
    }

    public void setTech_QQ(String tech_QQ) {
        this.tech_QQ = tech_QQ;
    }

    public String getTech_mobile() {
        return tech_mobile;
    }

    public void setTech_mobile(String tech_mobile) {
        this.tech_mobile = tech_mobile;
    }

    public String getTech_email() {
        return tech_email;
    }

    public void setTech_email(String tech_email) {
        this.tech_email = tech_email;
    }

    public String getOperation_QQ() {
        return operation_QQ;
    }

    public void setOperation_QQ(String operation_QQ) {
        this.operation_QQ = operation_QQ;
    }

    public String getOperation_mobile() {
        return operation_mobile;
    }

    public void setOperation_mobile(String operation_mobile) {
        this.operation_mobile = operation_mobile;
    }

    public String getOperation_email() {
        return operation_email;
    }

    public void setOperation_email(String operation_email) {
        this.operation_email = operation_email;
    }

    public String getCustomerService_QQ() {
        return customerService_QQ;
    }

    public void setCustomerService_QQ(String customerService_QQ) {
        this.customerService_QQ = customerService_QQ;
    }

    public String getCustomerService_mobile() {
        return customerService_mobile;
    }

    public void setCustomerService_mobile(String customerService_mobile) {
        this.customerService_mobile = customerService_mobile;
    }

    public String getCustomerService_email() {
        return customerService_email;
    }

    public void setCustomerService_email(String customerService_email) {
        this.customerService_email = customerService_email;
    }

    public String getAccountCheck_QQ() {
        return accountCheck_QQ;
    }

    public void setAccountCheck_QQ(String accountCheck_QQ) {
        this.accountCheck_QQ = accountCheck_QQ;
    }

    public String getAccountCheck_mobile() {
        return accountCheck_mobile;
    }

    public void setAccountCheck_mobile(String accountCheck_mobile) {
        this.accountCheck_mobile = accountCheck_mobile;
    }

    public String getAccountCheck_email() {
        return accountCheck_email;
    }

    public void setAccountCheck_email(String accountCheck_email) {
        this.accountCheck_email = accountCheck_email;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getGameNamePinYin() {
        return gameNamePinYin;
    }

    public void setGameNamePinYin(String gameNamePinYin) {
        this.gameNamePinYin = gameNamePinYin;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserEmail() {
        return userEmail;
    }

    public void setUserEmail(String userEmail) {
        this.userEmail = userEmail;
    }

    public String getPayCallBackUrl() {
        return payCallBackUrl;
    }

    public void setPayCallBackUrl(String payCallBackUrl) {
        this.payCallBackUrl = payCallBackUrl;
    }

    public String getAuditGameId() {
        return auditGameId;
    }

    public void setAuditGameId(String auditGameId) {
        this.auditGameId = auditGameId;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public Boolean getIsH5Game() {
        return isH5Game;
    }

    public void setIsH5Game(Boolean isH5Game) {
        this.isH5Game = isH5Game;
    }

    public String getH5LoginUrl() {
        return h5LoginUrl;
    }

    public void setH5LoginUrl(String h5LoginUrl) {
        this.h5LoginUrl = h5LoginUrl;
    }
}

==> xlniuxdata-mobileauditplatform-1.0.0-20160906.085435-13-sources.jar: com/xunlei/niux/data/auditplatform/vo/AuditMobileGameInfo.java <==
package com.xunlei.niux.data.auditplatform.vo;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by jamesjxin on 14-7-23.
 */
@Table(tableName = "auditmobilegameinfo", pkFieldAssign = false, pkFieldName = "seqId")
public class AuditMobileGameInfo {
    private Integer seqId;
    private Long userId;
    private String userEmail;
    private String userName;
    private String gameFullName;
    private String gameNamePinYin;
    private String appName;
    private Double appSize;
    private String versionNum;
    private String apkDownLoadUrl;
    private String gameMaterialUrl;
    private String gameIntroduction;
    private String gameDetailInfomation;
    private String currencyName;
    private Integer currencyExchangeRate;
    private Integer auditStatus;
    private String recordTime;
    private String auditTime;
    private String payCallBackUrl;

    private String business_QQ;
    private String business_mobile;
    private String business_email;
    private String tech_QQ;
    private String tech_mobile;
    private String tech_email;
    private String operation_QQ;
    private String operation_mobile;
    private String operation_email;
    private String customerService_QQ;
    private String customerService_mobile;
    private String customerService_email;
    private String accountCheck_QQ;
    private String accountCheck_mobile;
    private String accountCheck_email;
    private String auditGameId;
    private String companyName;
    private boolean isH5Game;

    public Integer getSeqId() {
        return seqId;
    }

    public void setSeqId(Integer seqId) {
        this.seqId = seqId;
    }

    public String getGameFullName() {
        return gameFullName;
    }

    public void setGameFullName(String gameFullName) {
        this.gameFullName = gameFullName;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Double getAppSize() {
        return appSize;
    }

    public void setAppSize(Double appSize) {
        this.appSize = appSize;
    }

    public String getVersionNum() {
        return versionNum;
    }

    public void setVersionNum(String versionNum) {
        this.versionNum = versionNum;
    }

    public String getApkDownLoadUrl() {
        return apkDownLoadUrl;
    }

    public void setApkDownLoadUrl(String apkDownLoadUrl) {
        this.apkDownLoadUrl = apkDownLoadUrl;
    }

    public String getGameMaterialUrl() {
        return gameMaterialUrl;
    }

    public void setGameMaterialUrl(String gameMaterialUrl) {
        this.gameMaterialUrl = gameMaterialUrl;
    }

    public String getGameIntroduction() {
        return gameIntroduction;
    }

    public void setGameIntroduction(String gameIntroduction) {
        this.gameIntroduction = gameIntroduction;
    }

    public String getGameDetailInfomation() {
        return gameDetailInfomation;
    }

    public void setGameDetailInfomation(String gameDetailInfomation) {
        this.gameDetailInfomation = gameDetailInfomation;
    }

    public String getCurrencyName() {
        return currencyName;
    }

    public void setCurrencyName(String currencyName) {
        this.currencyName = currencyName;
    }

    public Integer getCurrencyExchangeRate() {
        return currencyExchangeRate;
    }

    public void setCurrencyExchangeRate(Integer currencyExchangeRate) {
        this.currencyExchangeRate = currencyExchangeRate;
    }

    public Integer getAuditStatus() {
        return auditStatus;
    }

    public void setAuditStatus(Integer auditStatus) {
        this.auditStatus = auditStatus;
    }

    public String getRecordTime() {
        return recordTime;
    }

    public void setRecordTime(String recordTime) {
        this.recordTime = recordTime;
    }

    public String getAuditTime() {
        return auditTime;
    }

    public void setAuditTime(String auditTime) {
        this.auditTime = auditTime;
    }

    public String getBusiness_QQ() {
        return business_QQ;
    }

    public void setBusiness_QQ(String business_QQ) {
        this.business_QQ = business_QQ;
    }

    public String getBusiness_mobile() {
        return business_mobile;
    }

    public void setBusiness_mobile(String business_mobile) {
        this.business_mobile = business_mobile;
    }

    public String getBusiness_email() {
        return business_email;
    }

    public void setBusiness_email(String business_email) {
        this.business_email = business_email;
    }

    public String getTech_QQ() {
        return tech_QQ;
    }

    public void setTech_QQ(String tech_QQ) {
        this.tech_QQ = tech_QQ;
    }

    public String getTech_mobile() {
        return tech_mobile;
    }

    public void setTech_mobile(String tech_mobile) {
        this.tech_mobile = tech_mobile;
    }

    public String getTech_email() {
        return tech_email;
    }

    public void setTech_email(String tech_email) {
        this.tech_email = tech_email;
    }

    public String getOperation_QQ() {
        return operation_QQ;
    }

    public void setOperation_QQ(String operation_QQ) {
        this.operation_QQ = operation_QQ;
    }

    public String getOperation_mobile() {
        return operation_mobile;
    }

    public void setOperation_mobile(String operation_mobile) {
        this.operation_mobile = operation_mobile;
    }

    public String getOperation_email() {
        return operation_email;
    }

    public void setOperation_email(String operation_email) {
        this.operation_email = operation_email;
    }

    public String getCustomerService_QQ() {
        return customerService_QQ;
    }

    public void setCustomerService_QQ(String customerService_QQ) {
        this.customerService_QQ = customerService_QQ;
    }

    public String getCustomerService_mobile() {
        return customerService_mobile;
    }

    public void setCustomerService_mobile(String customerService_mobile) {
        this.customerService_mobile = customerService_mobile;
    }

    public String getCustomerService_email() {
        return customerService_email;
    }

    public void setCustomerService_email(String customerService_email) {
        this.customerService_email = customerService_email;
    }

    public String getAccountCheck_QQ() {
        return accountCheck_QQ;
    }

    public void setAccountCheck_QQ(String accountCheck_QQ) {
        this.accountCheck_QQ = accountCheck_QQ;
    }

    public String getAccountCheck_mobile() {
        return accountCheck_mobile;
    }

    public void setAccountCheck_mobile(String accountCheck_mobile) {
        this.accountCheck_mobile = accountCheck_mobile;
    }

    public String getAccountCheck_email() {
        return accountCheck_email;
    }

    public void setAccountCheck_email(String accountCheck_email) {
        this.accountCheck_email = accountCheck_email;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getGameNamePinYin() {
        return gameNamePinYin;
    }

    public void setGameNamePinYin(String gameNamePinYin) {
        this.gameNamePinYin = gameNamePinYin;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserEmail() {
        return userEmail;
    }

    public void setUserEmail(String userEmail) {
        this.userEmail = userEmail;
    }

    public String getPayCallBackUrl() {
        return payCallBackUrl;
    }

    public void setPayCallBackUrl(String payCallBackUrl) {
        this.payCallBackUrl = payCallBackUrl;
    }

    public String getAuditGameId() {
        return auditGameId;
    }

    public void setAuditGameId(String auditGameId) {
        this.auditGameId = auditGameId;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public boolean getIsH5Game() {
        return isH5Game;
    }

    public void setIsH5Game(boolean isH5Game) {
        this.isH5Game = isH5Game;
    }
}
